PCB Environment: RoutePainter Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Attributes
RoutePainter Class Reference

## Public Member Functions
void | update (const PCBoard &)
void | update (const Track &, uint zmax, Color)
void | setLineWidth (float w)
void | draw (const Camera &)
void | drawLayer (const Camera &, uint z)
void | setLayerColor (uint z, Color)
void | setLayerAlpha (uint z, float)
void | clear ()

## Static Public Attributes
static constexpr const uint | MaxLayers = 16

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/RoutePainter.hpp